@@ -3,6 +3,6 @@ vardist <- function (x)
     if (!is.numeric(x)) {
         stop("Only defined for numeric variables")
     }
-    y <- cbind(x,x)
+    y <- cbind(as.double(x),as.double(x))
     orddist(y)
 }
